diff --git a/src/components/dialog/index.vue b/src/components/dialog/index.vue
index 76ae82f..e2750dd 100644
--- a/src/components/dialog/index.vue
+++ b/src/components/dialog/index.vue
@@ -1,9 +1,11 @@
+
- 取 消
- 确 定
+ 取 消
+ 确 定
- 确 定
+ 确 定
@@ -57,14 +59,13 @@
\ No newline at end of file
diff --git a/src/pages/index/list/index.vue b/src/pages/index/list/index.vue
index 6366cdc..cbcb94c 100644
--- a/src/pages/index/list/index.vue
+++ b/src/pages/index/list/index.vue
@@ -48,6 +48,20 @@ export default {
}
},
created() {
+ if(!sessionStorage.getItem('firstLoad2')) {
+ const loading = this.$loading({
+ lock: true,
+ // text: 'Loading',
+ text: '努力加载中,请稍等哦...',
+ spinner: 'el-icon-loading',
+ background: 'rgba(0, 0, 0, 0.7)'
+ });
+ setTimeout(() => {
+ loading.close();
+ sessionStorage.setItem('firstLoad2', true)
+ }, 6000);
+ }
+
if(!this.businessKey) {
this.setShowBusiness(true)
}
diff --git a/src/pages/manage/list/business/openAccount.vue b/src/pages/manage/list/business/openAccount.vue
index 8361bc3..58f6e0b 100644
--- a/src/pages/manage/list/business/openAccount.vue
+++ b/src/pages/manage/list/business/openAccount.vue
@@ -27,8 +27,8 @@
-
-
+
+
@@ -50,16 +50,16 @@
checkName(val, form, 'customerName')" ref="customerName">
-
-
+
+
-
-
+
+
@@ -70,8 +70,8 @@
-
-
+
+
@@ -116,14 +116,14 @@ export default {
form:{
// 必填项
customerName: '', // 客户姓名
- accountNature: '', // 账户性质
+ accountQuality: '', // 账户性质
accountType: '', // 账户类型
accountManagement: '', // 账户科目
- currencyType: '', // 币种
- currencyMark: '', // 钞汇标识
+ currency: '', // 币种
+ goldLogo: '', // 钞汇标识
calculateWay: '', // 计息方式
outAccountWay: '', // 出账页标志
- withdrawingWay: '', // 支取方式
+ drawWay: '', // 支取方式
// 非必填项
customerNumber: '', // 客户号
clientNumber: '', // 统计代码
@@ -133,14 +133,14 @@ export default {
formName:{
// 必填项
customerName: '客户姓名', //
- accountNature: '账户性质', //
+ accountQuality: '账户性质', //
accountType: '账户类型', //
accountManagement: '账户科目', //
- currencyType: '币种', //
- currencyMark: '钞汇标识', //
+ currency: '币种', //
+ goldLogo: '钞汇标识', //
calculateWay: '计息方式', //
outAccountWay: '出账页标志', //
- withdrawingWay: '支取方式', //
+ drawWay: '支取方式', //
// 非必填项
customerNumber: '客户号', //
clientNumber: '统计代码', //
@@ -149,7 +149,7 @@ export default {
},
rules: {
// customerName: vercustomer,
- accountNature: [
+ accountQuality: [
{
required: true,
message: '请选择账户性质',
@@ -170,14 +170,14 @@ export default {
// trigger: 'blur'
// }
// ],
- // currencyType: [
+ // currency: [
// {
// required: true,
// message: '请选择币种',
// trigger: 'blur'
// }
// ],
- // currencyMark: [
+ // goldLogo: [
// {
// required: true,
// message: '请选择钞汇标识',
@@ -198,7 +198,7 @@ export default {
// trigger: 'blur'
// }
// ],
- // withdrawingWay: [
+ // drawWay: [
// {
// required: true,
// message: '请选择支取方式',
@@ -254,7 +254,7 @@ export default {
"subjectId": 7,
},
231: {
- prop: 'accountNature',
+ prop: 'accountQuality',
type: '1',
"subjectId": 10,
},
@@ -269,12 +269,12 @@ export default {
"subjectId": 38,
},
233: {
- prop: 'currencyType',
+ prop: 'currency',
type: '1',
"subjectId": 8,
},
234: {
- prop: 'currencyMark',
+ prop: 'goldLogo',
type: '1',
"subjectId": 9,
},
@@ -289,7 +289,7 @@ export default {
"subjectId": 40,
},
237: {
- prop: 'withdrawingWay',
+ prop: 'drawWay',
type: '1',
"subjectId": 13,
}
diff --git a/src/pages/manage/list/business/withdrawal.vue b/src/pages/manage/list/business/withdrawal.vue
index c29e3ea..60d3232 100644
--- a/src/pages/manage/list/business/withdrawal.vue
+++ b/src/pages/manage/list/business/withdrawal.vue
@@ -20,13 +20,13 @@
-
-
+
+
-
-
+
+
@@ -47,8 +47,8 @@
>
-
-
+
+
@@ -104,9 +104,9 @@ export default {
// 非必填项
issueDate: '', // 签发日期
currency: '', // 币种
- currencyMark: '', // 钞汇标识
- certificateType: '', // 凭证类型
- payWay: '', // 支取方式
+ goldLogo: '', // 钞汇标识
+ voucherType: '', // 凭证类型
+ drawWay: '', // 支取方式
abstract: '', // 摘要
},
formName:{
@@ -118,9 +118,9 @@ export default {
// 非必填项
issueDate: '签发日期', //
currency: '币种', //
- currencyMark: '钞汇标识', //
- certificateType: '凭证类型', //
- payWay: '支取方式', //
+ goldLogo: '钞汇标识', //
+ voucherType: '凭证类型', //
+ drawWay: '支取方式', //
abstract: '摘要', //
},
rules: {
@@ -187,17 +187,17 @@ export default {
"subjectId": 8,
},
252: {
- prop: 'currencyMark', // 1
+ prop: 'goldLogo', // 1
type: '1',
"subjectId": 9,
},
255: {
- prop: 'payWay',
+ prop: 'drawWay',
type: '3',
"subjectId": 13,
},
253: {
- prop: 'certificateType', // 1
+ prop: 'voucherType', // 1
type: '1',
"subjectId": 11,
},
@@ -237,10 +237,10 @@ export default {
getBlurData() {
if(this.form.username) {
this.form.currency = 12
- this.form.currencyMark = 13
+ this.form.goldLogo = 13
this.form.issueDate = '2022-01-05' // 调取该账户开户操作日期展示
- this.form.certificateType = 123
- this.form.payWay = 114
+ this.form.voucherType = 123
+ this.form.drawWay = 114
}
},
getFormData(){
diff --git a/src/pages/manage/list/client/corporateClient.vue b/src/pages/manage/list/client/corporateClient.vue
index 12e23b7..f91d05b 100644
--- a/src/pages/manage/list/client/corporateClient.vue
+++ b/src/pages/manage/list/client/corporateClient.vue
@@ -7,7 +7,7 @@
-
+
@@ -86,7 +86,7 @@ export default {
idNumber: '',
name: '',
phone: '',
- documentType: 82,
+ idType: 82,
companyName: '',
registeredCapital: '',
codeNumber: '',
@@ -97,7 +97,7 @@ export default {
idNumber: '法人证件号码',
name: '法人姓名',
phone: '联系电话',
- documentType: '证件类型',
+ idType: '证件类型',
companyName: '公司名称',
registeredCapital: '注册资本',
codeNumber: '代码证号',
@@ -179,7 +179,7 @@ export default {
if(data.status == 200) {
var list = data.data.judgmentRuleReqs
for (var i = 0; i < list.length; i++) {
- if (list[i].answerId == '48') {this.form.documentType = list[i].emptyTwo} //证件类型
+ if (list[i].answerId == '48') {this.form.idType = list[i].emptyTwo} //证件类型
else if (list[i].answerId == '49') {this.form.codeNumber = list[i].emptyTwo} //代码证号
else if (list[i].answerId == '50') {this.form.companyName = list[i].emptyTwo} //公司名称
else if (list[i].answerId == '51') {this.form.companyAddress = list[i].emptyTwo} //公司地址
@@ -238,8 +238,8 @@ export default {
// formList.push({"answerId":54,"emptyOne": "", "emptyTwo": firmClientIdentity, "operationIds": "285," + this.$store.state.system.businessSelect[this.$store.state.system.businessKey].id +",287,5,25,34,54","type": ""})// 法人证件号码
// }
formList.push({"answerId":54,"emptyOne": "", "emptyTwo": this.form.idNumber, "operationIds": "285," + this.$store.state.system.businessSelect[this.$store.state.system.businessKey].id +",287,5,25,34,54","type": ""})// 法人证件号码
- if(this.form.documentType){
- formList.push({ "answerId":'48', "emptyOne": "19", "emptyTwo": this.form.documentType, "operationIds": "285," + this.$store.state.system.businessSelect[this.$store.state.system.businessKey].id +",287,5,25,34,48","type": "1"})//证件类型
+ if(this.form.idType){
+ formList.push({ "answerId":'48', "emptyOne": "19", "emptyTwo": this.form.idType, "operationIds": "285," + this.$store.state.system.businessSelect[this.$store.state.system.businessKey].id +",287,5,25,34,48","type": "1"})//证件类型
}
if(this.form.companyAddress){
formList.push({ "answerId":'51', "emptyOne": "22", "emptyTwo": this.form.companyAddress, "operationIds": "285," + this.$store.state.system.businessSelect[this.$store.state.system.businessKey].id +",287,5,25,34,51", "type": "3" })//公司地址
diff --git a/src/pages/manage/list/personal/callDeposits/accountClosed.vue b/src/pages/manage/list/personal/callDeposits/accountClosed.vue
index 0d6b1f4..fa1cc8b 100644
--- a/src/pages/manage/list/personal/callDeposits/accountClosed.vue
+++ b/src/pages/manage/list/personal/callDeposits/accountClosed.vue
@@ -53,7 +53,7 @@
-
+
@@ -133,7 +133,7 @@ export default{
depositNumber: '', // 定存编号
capital: '', // 本金
interestRate: '', // 利率
- depositDate: '', // 存期
+ voucherType: '', // 存期
interest: '', // 利息
totalMoney: '', // 总金额
certificateType: '', //证件类型
@@ -157,7 +157,7 @@ export default{
depositNumber: '定存编号', //
capital: '本金', //
interestRate: '利率', //
- depositDate: '存期', //
+ voucherType: '存期', //
interest: '利息', //
totalMoney: '总金额', //
certificateType: '证件类型', //
@@ -284,9 +284,9 @@ export default{
if(this.needsModule(moduleName) === '') {
if(sessionStorage.getItem('nomCallDepositClosedCard')) {
this.cardNumberJudge = true
- const { depositDate, noticeType, depositNumber, capital, interest, totalMoney, idNumber,
+ const { noticeType, depositNumber, capital, interest, totalMoney, idNumber,
peopleNumber, userName, currency, goldLogo, voucherNumber, payMoney, voucherType } = this.dataFlow
- this.form.depositDate = depositDate
+ this.form.voucherType = 123
this.form.noticeType = noticeType
this.form.depositNumber = depositNumber
this.form.capital = capital
diff --git a/src/pages/manage/list/personal/callDeposits/openAccount.vue b/src/pages/manage/list/personal/callDeposits/openAccount.vue
index be0025f..9d92bb1 100644
--- a/src/pages/manage/list/personal/callDeposits/openAccount.vue
+++ b/src/pages/manage/list/personal/callDeposits/openAccount.vue
@@ -45,8 +45,8 @@
checkName(val, form, 'customerName')" ref="customerName">
-
-
+
+
@@ -113,7 +113,7 @@ export default{
drawPassword: '', // 支付密码
customerName: '', // 客户姓名
currency: 'CYN人民币', // 币种
- currencyMark: '钞户', // 钞汇标识
+ goldLogo: '钞户', // 钞汇标识
voucherType: 123, // 凭证类型
noticeType: '', // 通知类型
depositType: '', // '存款类别'
@@ -128,7 +128,7 @@ export default{
drawPassword: '支付密码', //
customerName: '客户姓名', //
currency: '币种', //
- currencyMark: '钞汇标识', //
+ goldLogo: '钞汇标识', //
voucherType: '凭证类型', //
noticeType: '通知类型', //
depositType: '存款类别', // ''
@@ -152,7 +152,7 @@ export default{
trigger: 'blur'
}
],
- currencyMark: [
+ goldLogo: [
{
required: true,
message: '请选择钞汇标识',
@@ -214,7 +214,7 @@ export default{
"subjectId": 8,
},
295: {
- prop: 'currencyMark',//钞汇标识
+ prop: 'goldLogo',//钞汇标识
type: '1',
"subjectId": 9,
},
@@ -278,7 +278,7 @@ export default{
this.form.clientNumber = peopleNumber
this.form.customerName = userName
this.form.currency = currency
- this.form.currencyMark = goldLogo
+ this.form.goldLogo = goldLogo
this.form.depositType = depositType
}
if(sessionStorage.getItem('nomCallDepositOpen3')) {
diff --git a/src/pages/manage/list/personal/timeDeposit/deposit.vue b/src/pages/manage/list/personal/timeDeposit/deposit.vue
index bfb19b0..6ce6604 100644
--- a/src/pages/manage/list/personal/timeDeposit/deposit.vue
+++ b/src/pages/manage/list/personal/timeDeposit/deposit.vue
@@ -23,8 +23,8 @@
-
-
+
+
@@ -38,8 +38,8 @@
checkName(val, form, 'customerName')">
-
-
+
+
@@ -110,7 +110,7 @@ export default{
// identityCard: '', // 身份证
customerName: '', // 客户姓名
currency: '', // 币种
- currencyMark: '', // 钞汇标识
+ goldLogo: '', // 钞汇标识
depositTerm: '', // 存期
extendPeriod: '', // 续存
certificateDeposit: 92, // 存款类别
@@ -120,14 +120,14 @@ export default{
// 非必填项
money: '', // 金额
interestRate: '', // 利率
- withdrawingWay: 18, // 支取方式
+ drawWay: 18, // 支取方式
abstract: '' // 摘要
},
formName:{
// 必填项
customerName: '客户姓名', //
currency: '币种', //
- currencyMark: '钞汇标识', //
+ goldLogo: '钞汇标识', //
depositTerm: '存期', //
extendPeriod: '续存', //
certificateDeposit: '存款类别', //
@@ -137,7 +137,7 @@ export default{
// 非必填项
money: '金额', //
interestRate: '利率', //
- withdrawingWay: '支取方式', //
+ drawWay: '支取方式', //
abstract: '摘要' //
},
rules: {
@@ -156,7 +156,7 @@ export default{
trigger: 'blur'
}
],
- currencyMark: [
+ goldLogo: [
{
required: true,
message: '请选择钞汇标识',
@@ -205,7 +205,7 @@ export default{
"subjectId": 14,
},
139: {
- prop: 'withdrawingWay',//支取方式
+ prop: 'drawWay',//支取方式
type: '1',
"subjectId": 28,
},
@@ -231,7 +231,7 @@ export default{
"subjectId": 8,
},
134: {
- prop: 'currencyMark',//钞汇标识
+ prop: 'goldLogo',//钞汇标识
type: '1',
"subjectId": 9,
},
@@ -276,7 +276,7 @@ export default{
const { userName, currency, goldLogo, voucherNumber } = this.dataFlow
this.form.customerName = userName
this.form.currency = currency
- this.form.currencyMark = goldLogo
+ this.form.goldLogo = goldLogo
this.form.voucherNumber = voucherNumber
}
@@ -311,7 +311,7 @@ export default{
// const { userName, currency, goldLogo } = this.dataFlow
// this.form.customerName = userName
// this.form.currency = currency
- // this.form.currencyMark = goldLogo
+ // this.form.goldLogo = goldLogo
}
},
getFormData(){
diff --git a/src/pages/manage/list/personal/timeDeposit/openAccount.vue b/src/pages/manage/list/personal/timeDeposit/openAccount.vue
index afab61d..efd7223 100644
--- a/src/pages/manage/list/personal/timeDeposit/openAccount.vue
+++ b/src/pages/manage/list/personal/timeDeposit/openAccount.vue
@@ -22,8 +22,8 @@
-
-
+
+
@@ -40,8 +40,8 @@
checkName(val, form, 'customerName')">
-
-
+
+
@@ -101,12 +101,12 @@ export default{
idNumber: '', // 身份证
customerName: '', // 客户姓名
currency: '', // 币种
- currencyMark: '', // 钞汇标识
+ goldLogo: '', // 钞汇标识
voucherType: 123, // 凭证类型
voucherNumber: '', // 凭证号码
drawPassword: '', // 支付密码
customerManage: '', // 客户经理
- withdrawingWay:18,//支取方式
+ drawWay:18,//支取方式
// 非必填项
certificateType: 83, // 证件类型
clientNumber: '' // 客户号
@@ -115,11 +115,11 @@ export default{
idNumber: '身份证', //
customerName: '客户姓名', //
currency: '币种', //
- currencyMark: '钞汇标识', //
+ goldLogo: '钞汇标识', //
voucherType: '凭证类型', //
voucherNumber: '凭证号码', //
customerManage: '客户经理', //
- withdrawingWay:'支取方式',//
+ drawWay:'支取方式',//
certificateType: '证件类型', //
drawPassword: '支付密码', //
clientNumber: '客户号' //
@@ -142,7 +142,7 @@ export default{
trigger: 'blur'
}
],
- currencyMark: [{
+ goldLogo: [{
required: true,
message: '请选择钞汇标识',
trigger: 'blur'
@@ -193,7 +193,7 @@ export default{
type: '3'
},
130: {
- prop: 'withdrawingWay', //支取方式
+ prop: 'drawWay', //支取方式
type: '1',
"subjectId": 13,
},
@@ -203,7 +203,7 @@ export default{
"subjectId": 8,
},
126: {
- prop: 'currencyMark',//钞汇标识
+ prop: 'goldLogo',//钞汇标识
type: '1',
"subjectId": 9,
},
@@ -225,7 +225,7 @@ export default{
this.form.idNumber = idNumber
this.form.customerName = userName
this.form.currency = currency
- this.form.currencyMark = goldLogo
+ this.form.goldLogo = goldLogo
this.idNumberJudge = true
console.log(this.idNumberJudge)
diff --git a/src/pages/manage/list/personal/timeDeposit/withdrawal.vue b/src/pages/manage/list/personal/timeDeposit/withdrawal.vue
index c75426d..aecca6d 100644
--- a/src/pages/manage/list/personal/timeDeposit/withdrawal.vue
+++ b/src/pages/manage/list/personal/timeDeposit/withdrawal.vue
@@ -12,8 +12,8 @@
inputListen(val, form, 'voucherNumber')">
-
-
+
+
@@ -36,8 +36,8 @@
checkName(val, form, 'customerName')" ref="customerName">
-
-
+
+
@@ -96,8 +96,8 @@ export default{
const { userName, currency, goldLogo, interest, depositNumber, capital, withdrawType, voucherNumber } = this.dataFlow
this.form.voucherNumber = voucherNumber
this.form.customerName = userName
- this.form.currencyType = currency
- this.form.currencyMark = goldLogo
+ this.form.currency = currency
+ this.form.goldLogo = goldLogo
this.form.interest = interest
this.form.depositNumber = depositNumber
this.form.capital = capital
@@ -116,8 +116,8 @@ export default{
const { userName, currency, goldLogo, interest, depositNumber, capital, withdrawType, voucherNumber } = this.dataFlow
this.form.voucherNumber = voucherNumber
this.form.customerName = userName
- this.form.currencyType = currency
- this.form.currencyMark = goldLogo
+ this.form.currency = currency
+ this.form.goldLogo = goldLogo
this.form.interest = interest
this.form.depositNumber = depositNumber
this.form.capital = capital
@@ -159,7 +159,7 @@ export default{
// 必填项
drawPassword: '', // 凭证密码
cardNumber: '', // 凭证号码
- currencyMark: '', // 钞汇标识
+ goldLogo: '', // 钞汇标识
capital: '', // 本金
interest: '', // 利息
withdrawAmount: '', // 支取金额
@@ -169,7 +169,7 @@ export default{
// 非必填项
customerName: '', // 客户姓名
depositNumber: '', // 定存编号
- currencyType: '', // 币种
+ currency: '', // 币种
// userName, 这是vuex里的
// currency:'CNY人民币',
@@ -184,7 +184,7 @@ export default{
// 必填项
drawPassword: '凭证密码', //
cardNumber: '凭证号码', //
- currencyMark: '钞汇标识', //
+ goldLogo: '钞汇标识', //
capital: '本金', //
interest: '利息', //
withdrawAmount: '支取金额', //
@@ -194,7 +194,7 @@ export default{
// 非必填项
customerName: '客户姓名', //
depositNumber: '定存编号', //
- currencyType: '币种', //
+ currency: '币种', //
},
rules: {
customerName: vercustomer,
@@ -231,12 +231,12 @@ export default{
type: '3'
},
146: {
- prop: 'currencyType',//币种
+ prop: 'currency',//币种
type: '1',
"subjectId": 8,
},
147: {
- prop: 'currencyMark',//钞汇标识
+ prop: 'goldLogo',//钞汇标识
type: '1',
"subjectId": 9,
},
@@ -322,8 +322,8 @@ export default{
const { userName, currency, goldLogo, interest, depositNumber, capital, withdrawType, voucherNumber } = this.dataFlow
this.form.voucherNumber = voucherNumber
this.form.customerName = userName
- this.form.currencyType = currency
- this.form.currencyMark = goldLogo
+ this.form.currency = currency
+ this.form.goldLogo = goldLogo
this.form.interest = interest
this.form.depositNumber = depositNumber
this.form.capital = capital
@@ -342,8 +342,8 @@ export default{
const { userName, currency, goldLogo, interest, depositNumber, capital, withdrawType, voucherNumber } = this.dataFlow
this.form.voucherNumber = voucherNumber
this.form.customerName = userName
- this.form.currencyType = currency
- this.form.currencyMark = goldLogo
+ this.form.currency = currency
+ this.form.goldLogo = goldLogo
this.form.interest = interest
this.form.depositNumber = depositNumber
this.form.capital = capital
diff --git a/src/pages/manage/list/personal/usefulPhrases/accountClosed.vue b/src/pages/manage/list/personal/usefulPhrases/accountClosed.vue
index 1702234..6555c12 100644
--- a/src/pages/manage/list/personal/usefulPhrases/accountClosed.vue
+++ b/src/pages/manage/list/personal/usefulPhrases/accountClosed.vue
@@ -6,7 +6,7 @@
-
+
@@ -56,8 +56,8 @@
checkName(val, form, 'customerName')">
-
-
+
+
@@ -132,7 +132,7 @@ export default{
this.form.currency = currency
this.form.customerName = userName
this.form.depositNumber = depositNumber
- this.form.currencyMark = goldLogo
+ this.form.goldLogo = goldLogo
this.form.capital = capital
this.form.interestRate = interestRate
this.form.interest = interest
@@ -173,7 +173,7 @@ export default{
// 非必填项
certificateType: '', // 证件类型
customerName: '', // 客户姓名
- currencyMark: '', // 钞汇标识
+ goldLogo: '', // 钞汇标识
depositNumber: '', // 定存编号
capital: '', // 本金
interestRate: '', // 利率
@@ -191,7 +191,7 @@ export default{
// 非必填项
certificateType: '证件类型', //
customerName: '客户姓名', //
- currencyMark: '钞汇标识', //
+ goldLogo: '钞汇标识', //
depositNumber: '定存编号', //
capital: '本金', //
interestRate: '利率', //
@@ -230,7 +230,7 @@ export default{
"subjectId": 19,
},
184: {
- prop: 'currencyMark',//钞汇标识
+ prop: 'goldLogo',//钞汇标识
type: '1',
"subjectId": 9,
},
diff --git a/src/pages/manage/list/personal/usefulPhrases/continueDeposit.vue b/src/pages/manage/list/personal/usefulPhrases/continueDeposit.vue
index ae82cfc..16f9340 100644
--- a/src/pages/manage/list/personal/usefulPhrases/continueDeposit.vue
+++ b/src/pages/manage/list/personal/usefulPhrases/continueDeposit.vue
@@ -15,8 +15,8 @@
checkHanzi(val, form, 'depositNumber')">
-
-
+
+
@@ -84,7 +84,7 @@ export default{
this.form.currency = currency
this.form.depositTerm = depositTerm
this.form.depositNumber = depositNumber
- this.form.moneyTarget = goldLogo
+ this.form.goldLogo = goldLogo
this.form.monthDeposit = monthDeposit
}
if(sessionStorage.getItem('nomUsefulPhrasesContinuePassword')) {
@@ -116,7 +116,7 @@ export default{
drawPassword: '', // 支付密码
// 非必填项
depositNumber: '', // 定存编号
- moneyTarget: '', // 钞汇标识
+ goldLogo: '', // 钞汇标识
monthDeposit: '' // 月存金额
},
formName:{
@@ -128,7 +128,7 @@ export default{
drawPassword: '支付密码', //
// 非必填项
depositNumber: '定存编号', //
- moneyTarget: '钞汇标识', //
+ goldLogo: '钞汇标识', //
monthDeposit: '月存金额', //
@@ -152,7 +152,7 @@ export default{
},
myTable: {
175: {
- prop: 'moneyTarget',//钞汇标识
+ prop: 'goldLogo',//钞汇标识
type: '1',
"subjectId": 9,
},
diff --git a/src/pages/manage/list/personal/usefulPhrases/openAccount.vue b/src/pages/manage/list/personal/usefulPhrases/openAccount.vue
index 1f2cf1b..53bf265 100644
--- a/src/pages/manage/list/personal/usefulPhrases/openAccount.vue
+++ b/src/pages/manage/list/personal/usefulPhrases/openAccount.vue
@@ -50,8 +50,8 @@
checkName(val, form, 'customerName')">
-
-
+
+
@@ -115,7 +115,7 @@ export default{
this.form.idNumber = idNumber
this.form.customerName = userName
this.form.currency = currency
- this.form.currencyMark = goldLogo
+ this.form.goldLogo = goldLogo
this.form.voucherType = 127
}
if(sessionStorage.getItem('nomUsefulPhrasesOpenCard')) {
@@ -154,7 +154,7 @@ export default{
idNumber: '',
customerName: '', // 客户姓名
currency: '', // 币种
- currencyMark: '', // 钞汇标识
+ goldLogo: '', // 钞汇标识
voucherType: '', // 凭证类型
monthDeposit: '', // 月存金额
depositTerm: '', // 存期
@@ -171,7 +171,7 @@ export default{
idNumber: '身份证',
customerName: '客户姓名', //
currency: '币种', //
- currencyMark: '钞汇标识', //
+ goldLogo: '钞汇标识', //
voucherType: '凭证类型', //
monthDeposit: '月存金额', //
depositTerm: '存期', //
@@ -192,7 +192,7 @@ export default{
trigger: 'blur'
}
],
- currencyMark: [
+ goldLogo: [
{
required: true,
message: '请选择钞汇标识',
@@ -262,7 +262,7 @@ export default{
"subjectId": 8,
},
163: {
- prop: 'currencyMark',//钞汇标识
+ prop: 'goldLogo',//钞汇标识
type: '1',
"subjectId": 9,
},
diff --git a/src/pages/manage/list/business/deposit.vue b/src/pages/manage/list/business/deposit.vue
index af8aad3..749860a 100644
--- a/src/pages/manage/list/business/deposit.vue
+++ b/src/pages/manage/list/business/deposit.vue
@@ -24,8 +24,8 @@
checkName(val, form, 'customerName')" ref="customerName">
-
-
+
+
@@ -79,7 +79,7 @@ export default {
depositNum: '', // 存款金额
// 非必填项
currency: '', // 币种
- currencyMark: '', // 钞汇标识
+ goldLogo: '', // 钞汇标识
interestRate: '', // 利率
abstract: '', // 摘要
},
@@ -90,7 +90,7 @@ export default {
depositNum: '存款金额', //
// 非必填项
currency: '币种', //
- currencyMark: '钞汇标识', //
+ goldLogo: '钞汇标识', //
interestRate: '利率', //
abstract: '摘要', //
},
@@ -125,8 +125,8 @@ export default {
// if(this.form.currency){
// formList.push({ "answerId":'242', "emptyOne": "19", "emptyTwo": this.form.currency, "operationIds": parentId + ',242', "type": "1" })//客户号
// }
// if(this.form.currencyMark){
// formList.push({ "answerId":'243', "emptyOne": "7", "emptyTwo": this.form.currencyMark, "operationIds": parentId + ',243', "type": "3" })//统计代码
// }
// if(this.form.interestRate){
// formList.push( {"answerId":'245',"emptyOne": "5", "emptyTwo": this.form.interestRate, "operationIds": parentId + ",245", "type": "3"})//外汇核准号
@@ -141,7 +141,7 @@ export default {
"subjectId": 8,
},
243: {
- prop: 'currencyMark',
+ prop: 'goldLogo',
type: '1',
"subjectId": 9,
},
@@ -199,7 +199,7 @@ export default {
if(this.form.username) {
this.form.currency = 12
this.form.interestRate = 0.30
- this.form.currencyMark = 13
+ this.form.goldLogo = 13
}
},
getFormData(){
@@ -125,8 +125,8 @@ export default {
// formList.push({ "answerId":'242', "emptyOne": "19", "emptyTwo": this.form.currency, "operationIds": parentId + ',242', "type": "1" })//客户号
// }
- // if(this.form.currencyMark){
- // formList.push({ "answerId":'243', "emptyOne": "7", "emptyTwo": this.form.currencyMark, "operationIds": parentId + ',243', "type": "3" })//统计代码
+ // if(this.form.goldLogo){
+ // formList.push({ "answerId":'243', "emptyOne": "7", "emptyTwo": this.form.goldLogo, "operationIds": parentId + ',243', "type": "3" })//统计代码
// }
// if(this.form.interestRate){